==> typescript-node-scripts-0.1.4.tgz: package/lib/formatTsLoaderMessages.js <==
const fs = require('fs')
const textTable = require('text-table')
const stripAnsi = require('strip-ansi')

/**
 * Creates an array with the number range
 * Example: range(1, 4) => [1, 2, 3, 4]
 * @param {number} min
 * @param {number} max
 */
const range = (min, max) => {
    const len = max - min + 1
    return Array.from({ length: len }).map((_, i) => i + min)
}

/**
 * Creates an array where mid is the middle number in an array,
 * and padded by padLength number of elements on the left and right
 * Example: padNumber(4, 3) => [1, 2, 3, 4, 5, 6, 7]
 * @param {number} mid
 * @param {number} padLength
 */
const padNumber = (mid, padLength) => range(mid - padLength, mid + padLength)

module.exports = (error, colors) => {
    const friendlyMessage =
        error.content + ' ' + colors.cyan('(TS' + error.code + ')')

    // if there are no source files to parse, return only the message
    if (!error.file) {
        return friendlyMessage
    }

    // try to load the file
    let fileContents = ''
    try {
        fileContents = fs.readFileSync(error.file, 'utf-8')
    } catch (e) {
        return colors.red(
            '[TNS] Unable to read file ' + error.file + '\nReason: ' + e.message
        )
    }

    const SEPERATOR = colors.dim('│')

    const lines = fileContents.split('\n')
    const parsedLines = padNumber(error.line, 2)

    /**
     * Parse the line contents into a 2D array where one line is an array of
     * [line number, seperator, content]
     */
    const parsedContent = parsedLines.reduce((acc, line) => {
        const lineContent = lines[line - 1]
        const isSourceLine = line === error.line
        const sourceLine = isSourceLine
            ? colors.redBright('> ' + line)
            : colors.dim(line)

        if (lineContent !== undefined) {
            if (isSourceLine) {
                return [
                    ...acc,
                    [sourceLine, SEPERATOR, lineContent],
                    [
                        '',
                        SEPERATOR,
                        ' '.repeat(error.character - 1) + colors.redBright('^')
                    ]
                ]
            } else {
                return [...acc, [sourceLine, SEPERATOR, lineContent]]
            }
        } else {
            return acc
        }
    }, [])

    return [
        friendlyMessage,
        textTable(parsedContent, {
            align: ['r', 'c', 'l'],
            stringLength: l => stripAnsi(l).length
        })
    ].join('\n\n')
}

==> typescript-node-scripts-0.1.9.tgz: package/lib/formatTsLoaderMessages.js <==
const fs = require('fs')
const textTable = require('text-table')
const stripAnsi = require('strip-ansi')

/**
 * Creates an array with the number range
 * Example: range(1, 4) => [1, 2, 3, 4]
 * @param {number} min
 * @param {number} max
 */
const range = (min, max) => {
    const len = max - min + 1
    return Array.from({ length: len }).map((_, i) => i + min)
}

/**
 * Creates an array where mid is the middle number in an array,
 * and padded by padLength number of elements on the left and right
 * Example: padNumber(4, 3) => [1, 2, 3, 4, 5, 6, 7]
 * @param {number} mid
 * @param {number} padLength
 */
const padNumber = (mid, padLength) => range(mid - padLength, mid + padLength)

module.exports = (error, colors) => {
    const friendlyMessage =
        error.content + ' ' + colors.cyan('(TS' + error.code + ')')

    // if there are no source files to parse, return only the message
    if (!error.file) {
        return friendlyMessage
    }

    // try to load the file
    let fileContents = ''
    try {
        fileContents = fs.readFileSync(error.file, 'utf-8')
    } catch (e) {
        return colors.red(
            '[TNS] Unable to read file ' + error.file + '\nReason: ' + e.message
        )
    }

    const SEPERATOR = colors.dim('│')

    const lines = fileContents.split('\n')
    const parsedLines = padNumber(error.line, 2)

    /**
     * Parse the line contents into a 2D array where one line is an array of
     * [line number, seperator, content]
     */
    const parsedContent = parsedLines.reduce((acc, line) => {
        const isSourceLine = line === error.line
        const lineContent = isSourceLine
            ? lines[line - 1]
            : colors.dim(lines[line - 1])
        const sourceLine = isSourceLine
            ? colors.redBright('> ' + line)
            : colors.dim(line)

        if (lineContent !== undefined) {
            if (isSourceLine) {
                return [
                    ...acc,
                    [sourceLine, SEPERATOR, lineContent],
                    [
                        '',
                        SEPERATOR,
                        ' '.repeat(error.character - 1) + colors.redBright('^'),
                    ],
                ]
            } else {
                return [...acc, [sourceLine, SEPERATOR, lineContent]]
            }
        } else {
            return acc
        }
    }, [])

    return [
        friendlyMessage,
        textTable(parsedContent, {
            align: ['r', 'c', 'l'],
            stringLength: l => stripAnsi(l).length,
        }),
    ].join('\n\n')
}
